@@ -799,7 +799,7 @@ def new_branch(filepath, git, f_branch, f_tag, n_branch):
     if f_tag and len(f_tag) > 0:
         git_create_branch += " " + f_tag
     # checkout
-    git_checkout_command = "git checkout -b" + n_branch
+    git_checkout_command = "git checkout -b " + n_branch
     # git push
     git_push_command = "git push origin {0}".format(n_branch)
     os.system(git_push_command)
@@ -943,7 +943,7 @@ def release_branch(module_list, tag_path, c_path, f_branch):
     for a in module_list:
         if not (a.branch and len(a.branch) > 0) and not (a.tag and len(a.tag) > 0):
             a.branch = f_branch
-        if (a.branch and len(a.branch) > 0):
+        if a.branch and len(a.branch) > 0:
             filename = get_filename(a.git)
             module_path = tag_path + filename + "/"
             create_tag = auto_release_path(module_path, a.git, a.pod, a.branch, a.new_tag)
@@ -1070,8 +1070,7 @@ class yhgit:
         local_dependenceList = podfile_module_data["dependencies"]
         # 转换成模型数组
         module_list = load_yaml(local_dependenceList)
-        print("开始转换了")
-        print(modules)
+        debugInfo("开始转换了")
         status_result = []
         for module in module_list:
             result = 0
@@ -1121,7 +1120,7 @@ class yhgit:
     def commit(self, msg):
         """
         基于podfileModules的配置信息，提交本地开发分支代码
-        :param exeption_module_list: 这些模块不需要修改，不能提交代码
+        :param msg: 这些模块不需要修改，不能提交代码
         :return:
         """
         fa_path = ""
